@@ -1,7 +1,7 @@
 try:
-    import unittest2 as unittest
-except:
     import unittest
+except ImportError:
+    import unittest2 as unittest
 
 from mpegdash.parser import MPEGDASHParser
 
@@ -48,6 +48,44 @@ class XML2MPDTestCase(unittest.TestCase):
         self.assertTrue(mpd.periods[0].event_streams[0].events[1].message_data is None)
         self.assertEqual(mpd.periods[0].event_streams[0].events[1].event_value, "Some Random Event Text")
 
+    def test_xml2mpd_parse_vector_type_attributes(self):
+        mpd_string = '''
+        <MPD xmlns="urn:mpeg:DASH:schema:MPD:2011" mediaPresentationDuration="PT0H1M52.43S" minBufferTime="PT1.5S"
+        profiles="urn:mpeg:dash:profile:isoff-on-demand:2011" type="static">
+          <Period duration="PT0H1M52.43S" start="PT0S">
+            <AdaptationSet>
+              <ContentComponent contentType="video" id="1" />
+              <Representation bandwidth="4190760" codecs="avc1.640028" height="1080" id="1" mimeType="video/mp4" width="1920">
+                <SubRepresentation bandwidth="117600" codecs="mp4a.40.5" contentComponent="102 104"></SubRepresentation>
+                <BaseURL>motion-20120802-89.mp4</BaseURL>
+                <SegmentBase indexRange="674-981">
+                  <Initialization range="0-673" />
+                </SegmentBase>
+              </Representation>
+            </AdaptationSet>
+          </Period>
+        </MPD>
+        '''
+        mpd = MPEGDASHParser.parse(mpd_string)
+        self.assert_mpd(mpd)
+
+        sub_rep = mpd.periods[0].adaptation_sets[0].representations[0].sub_representations[0]
+        self.assertEqual(len(sub_rep.content_component), 2)
+        self.assertEqual(sub_rep.content_component[0], '102')
+        self.assertEqual(sub_rep.content_component[1], '104')
+
+    def test_xml2mpd_from_file_with_content_protection(self):
+        mpd = MPEGDASHParser.parse('./tests/mpd-samples/with_content_protection.mpd')
+        self.assertEqual(
+          "6c28b624-5854-5b8c-8033-9d61ac0c039c",
+          mpd.periods[0].adaptation_sets[0].content_protections[0].cenc_default_kid
+        )
+        self.assertEqual(
+          "urn:mpeg:dash:mp4protection:2011",
+          mpd.periods[0].adaptation_sets[0].content_protections[0].scheme_id_uri
+        )
+        self.assertTrue(mpd.periods[0].adaptation_sets[0].content_protections[1].pssh[0].pssh is not None)
+
     def assert_mpd(self, mpd):
         self.assertTrue(mpd is not None)
         self.assertTrue(len(mpd.periods) > 0)
